@@ -6,10 +6,11 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.008002";
+    our $MITE_VERSION = "0.008003";
 
     BEGIN {
         require Scalar::Util;
+        *STRICT  = \&Mite::Shim::STRICT;
         *bare    = \&Mite::Shim::bare;
         *blessed = \&Scalar::Util::blessed;
         *carp    = \&Mite::Shim::carp;
@@ -142,9 +143,8 @@
     }
     else {
         *app = sub {
-            @_ > 1
-              ? croak("app is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"app"};
+            @_ == 1 or croak('Reader "app" usage: $self->app()');
+            $_[0]{"app"};
         };
     }
 
@@ -163,9 +163,9 @@
     # Accessors for kingpin_command
     # has declaration, file lib/Mite/App/Command.pm, line 19
     sub kingpin_command {
-        @_ > 1
-          ? croak("kingpin_command is a read-only attribute of @{[ref $_[0]]}")
-          : (
+        @_ == 1
+          or croak('Reader "kingpin_command" usage: $self->kingpin_command()');
+        (
             exists( $_[0]{"kingpin_command"} ) ? $_[0]{"kingpin_command"} : (
                 $_[0]{"kingpin_command"} = do {
                     my $default_value = $_[0]->_build_kingpin_command;
@@ -175,7 +175,7 @@
                     $default_value;
                 }
             )
-          );
+        );
     }
 
     1;
