@@ -6,10 +6,11 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.008002";
+    our $MITE_VERSION = "0.008003";
 
     BEGIN {
         require Scalar::Util;
+        *STRICT  = \&Mite::Shim::STRICT;
         *bare    = \&Mite::Shim::bare;
         *blessed = \&Scalar::Util::blessed;
         *carp    = \&Mite::Shim::carp;
@@ -445,12 +446,16 @@
 
     # Accessors for parents
     # has declaration, file lib/Mite/Class.pm, line 36
-    sub _clear_parents { delete $_[0]{"parents"}; $_[0]; }
+    sub _clear_parents {
+        @_ == 1
+          or croak('Clearer "_clear_parents" usage: $self->_clear_parents()');
+        delete $_[0]{"parents"};
+        $_[0];
+    }
 
     sub parents {
-        @_ > 1
-          ? croak("parents is a read-only attribute of @{[ref $_[0]]}")
-          : (
+        @_ == 1 or croak('Reader "parents" usage: $self->parents()');
+        (
             exists( $_[0]{"parents"} ) ? $_[0]{"parents"} : (
                 $_[0]{"parents"} = do {
                     my $default_value = $_[0]->_build_parents;
@@ -477,7 +482,7 @@
                     $default_value;
                 }
             )
-          );
+        );
     }
 
     1;
