@@ -6,10 +6,11 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.008002";
+    our $MITE_VERSION = "0.008003";
 
     BEGIN {
         require Scalar::Util;
+        *STRICT  = \&Mite::Shim::STRICT;
         *bare    = \&Mite::Shim::bare;
         *blessed = \&Scalar::Util::blessed;
         *carp    = \&Mite::Shim::carp;
@@ -327,9 +328,8 @@
     }
     else {
         *source = sub {
-            @_ > 1
-              ? croak("source is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"source"};
+            @_ == 1 or croak('Reader "source" usage: $self->source()');
+            $_[0]{"source"};
         };
     }
 
