@@ -6,7 +6,7 @@ package Mite::Project;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008002';
+our $VERSION   = '0.008003';
 
 has sources =>
   is            => ro,
@@ -247,7 +247,7 @@ sub inject_mite_functions {
         *{"$package\::$f"} = \&{"$shim\::$f"};
         $pkg->imported_functions->{$f} = "$shim\::$f";
     }
-    for my $f ( qw/ carp croak confess guard / ) {
+    for my $f ( qw/ carp croak confess guard STRICT / ) {
         next unless $requested->( $f, false );
         *{"$package\::$f"} = \&{"$shim\::$f"};
         $pkg->imported_functions->{$f} = "$shim\::$f";
