@@ -6,10 +6,11 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.008002";
+    our $MITE_VERSION = "0.008003";
 
     BEGIN {
         require Scalar::Util;
+        *STRICT  = \&Mite::Shim::STRICT;
         *bare    = \&Mite::Shim::bare;
         *blessed = \&Scalar::Util::blessed;
         *carp    = \&Mite::Shim::carp;
@@ -236,7 +237,8 @@
     # Accessors for config
     # has declaration, file lib/Mite/Project.pm, line 24
     sub config {
-        @_ > 1 ? croak("config is a read-only attribute of @{[ref $_[0]]}") : (
+        @_ == 1 or croak('Reader "config" usage: $self->config()');
+        (
             exists( $_[0]{"config"} ) ? $_[0]{"config"} : (
                 $_[0]{"config"} = do {
                     my $default_value =
@@ -281,9 +283,8 @@
     }
     else {
         *sources = sub {
-            @_ > 1
-              ? croak("sources is a read-only attribute of @{[ref $_[0]]}")
-              : $_[0]{"sources"};
+            @_ == 1 or croak('Reader "sources" usage: $self->sources()');
+            $_[0]{"sources"};
         };
     }
 
@@ -473,7 +474,7 @@
 "Type check failed in signature for inject_mite_functions: %s should be %s",
                 "\$_{\"x_source\"}", "Optional[Object]"
               );
-            $out{"x_source"} = $in{"x_source"} if exists( $in{"x_source"} );
+            $out{"x_source"} = $in{"x_source"};
             delete( $in{"x_source"} );
         }
 
@@ -491,7 +492,7 @@
 "Type check failed in signature for inject_mite_functions: %s should be %s",
                 "\$_{\"x_pkg\"}", "Optional[Object]"
               );
-            $out{"x_pkg"} = $in{"x_pkg"} if exists( $in{"x_pkg"} );
+            $out{"x_pkg"} = $in{"x_pkg"};
             delete( $in{"x_pkg"} );
         }
 
