@@ -6,7 +6,7 @@ package Mite::Role;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008002';
+our $VERSION   = '0.008003';
 
 use Path::Tiny;
 use B ();
@@ -170,6 +170,17 @@ sub project {
     return $self->source->project;
 }
 
+sub autolax {
+    my $self = shift;
+
+    return undef
+        if not eval { $self->project->config->data->{autolax} };
+
+    return $self->imported_functions->{STRICT}
+        ? 'STRICT'
+        : sprintf( '%s::STRICT', $self->project->config->data->{shim} );
+}
+
 signature_for add_attributes => (
     pos => [ slurpy ArrayRef[InstanceOf['Mite::Attribute']] ],
 );
