@@ -6,7 +6,7 @@ package Mite::Signature;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008002';
+our $VERSION   = '0.008003';
 
 has class =>
   is            => ro,
@@ -74,6 +74,15 @@ sub BUILD {
         if $self->is_named && $self->is_positional;
 }
 
+sub autolax {
+    my $self = shift;
+
+    my $class = $self->compiling_class || $self->class;
+    return if not $class;
+    return if not eval { $class->project->config->data->{autolax} };
+    return sprintf '%s::STRICT', $class->project->config->data->{shim};
+}
+
 sub _build_compiler {
     my $self = shift;
 
@@ -89,6 +98,7 @@ sub _build_compiler {
             ( $self->head ? ( head => $self->head ) : () ),
             ( $self->tail ? ( tail => $self->tail ) : () ),
             named_to_list  => $self->named_to_list,
+            strictness     => scalar( $self->autolax // 1 ),
             mite_signature => $self,
             $self->should_bless
                 ? ( bless => sprintf '%s::__NAMED_ARGUMENTS__::%s', $self->class->name, $self->method_name )
